Rumamge.Phoenix v2.0.0 Rummage.Phoenix.View View Source

View Module for Rummage. This has view helpers that can generate rummagable links and forms.

Usage:

defmodule MyApp.ProductView do
  use MyApp.Web, :view
  use Rummage.Phoenix.View
end

Link to this section Summary

Functions

This macro includes the helpers functions from different Rummage.Phoenix.Views

Link to this section Functions

Link to this macro

__using__(opts)

View Source (macro)

This macro includes the helpers functions from different Rummage.Phoenix.Views